OC.L10N.register(
    "files_external",
    {
    "External storages" : "外部ストレージ",
    "Personal" : "個人",
    "System" : "システム",
    "Grant access" : "アクセスを許可",
    "Error configuring OAuth1" : "OAuth1設定エラー",
    "Please provide a valid app key and secret." : "有効なアプリのキーとパスワードを入力してください。",
    "Error configuring OAuth2" : "OAuth2設定エラー",
    "Generate keys" : "キーを生成",
    "Error generating key pair" : "キーペアの生成エラー",
    "All users. Type to select user or group." : "すべてのユーザー。ユーザー、グループを追加",
    "(group)" : "(グループ)",
    "Compatibility with Mac NFD encoding (slow)" : "Mac NFD エンコード互換 (遅い)",
    "Enable encryption" : "暗号化を有効に",
    "Enable previews" : "プレビューを有効に",
    "Enable sharing" : "共有の有効化",
    "Check for changes" : "変更点を確認",
    "Never" : "更新無",
    "Once every direct access" : "直指定時のみ",
    "Read only" : "読み取り専用",
    "Delete" : "削除",
    "Admin defined" : "管理者設定済",
    "Are you sure you want to delete this external storage?" : "この外部ストレージを本当に削除しますか?",
    "Delete storage?" : "ストレージを削除しますか?",
    "Saved" : "保存しました",
    "Saving..." : "保存中...",
    "Save" : "保存",
    "Empty response from the server" : "サーバーから空の応答がありました",
    "Couldn't access. Please log out and in again to activate this mount point" : "アクセスできません。ログアウトして、再度このマウントポイントをアクティベートしてください。",
    "Couldn't get the information from the remote server: {code} {type}" : "リモートサーバーから情報を取得できませんでした：{code} {type}",
    "Couldn't get the list of external mount points: {type}" : "外部マウントポイントのリストを取得できませんでした。: {type}",
    "There was an error with message: " : "メッセージ付きのエラーが発生しました：",
    "External mount error" : "外部マウントエラー",
    "external-storage" : "外部ストレージ",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Windowsネットワークドライブのマウントポイントのリストが取得できませんでした: サーバーからのレスポンスは空でした。",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "いくつかの設定済み外部マウントポイントに接続できませんでした。詳細情報は赤い行をクリックしてください",
    "Please enter the credentials for the {mount} mount" : " {mount} のマウントのために必要な資格情報を入力してください",
    "Username" : "ユーザー名",
    "Password" : "パスワード",
    "Credentials saved" : "資格情報を保存しました",
    "Credentials saving failed" : "資格情報の保存に失敗しました",
    "Credentials required" : "資格情報が必要です",
    "Storage with ID \"%d\" not found" : "ID \"%d\" のストレージが見つかりません",
    "Invalid backend or authentication mechanism class" : "バックエンドまたは認証システムクラスが無効",
    "Invalid mount point" : "無効なマウントポイント",
    "Objectstore forbidden" : "オブジェクトストアが禁じられています",
    "Invalid storage backend \"%s\"" : "\"%s\" のストレージバックエンドが不正",
    "Not permitted to use backend \"%s\"" : "バックエンド %s を使うための権限がありません",
    "Not permitted to use authentication mechanism \"%s\"" : "認証システム %s を使う権限がありません",
    "Unsatisfied backend parameters" : "バックエンドのためのパラメーターが不十分です。",
    "Unsatisfied authentication mechanism parameters" : "認証のためのパラメータが不十分です",
    "Insufficient data: %s" : "データが不足しています: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "ID \"%d\" のストレージはユーザーが編集できません",
    "Access key" : "アクセスキー",
    "Secret key" : "シークレットキー",
    "Builtin" : "ビルトイン",
    "None" : "なし",
    "OAuth1" : "OAuth1",
    "App key" : "アプリキー",
    "App secret" : "アプリシークレット",
    "OAuth2" : "OAuth2",
    "Client ID" : "クライアントID",
    "Client secret" : "クライアント秘密キー",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "テナント名",
    "Identity endpoint URL" : "認証エンドポイントURL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "ドメイン",
    "Rackspace" : "Rackspace",
    "API key" : "APIキー",
    "Global credentials" : "グローバル資格情報",
    "Log-in credentials, save in database" : "ログイン認証情報は、データベースに保存されます。",
    "Username and password" : "ユーザー名とパスワード",
    "Log-in credentials, save in session" : "ログイン認証情報は、セッションに保存されます。",
    "User entered, store in database" : "入力されたユーザーデータは、データベースに保管します",
    "RSA public key" : "RSA公開鍵",
    "Public key" : "公開鍵",
    "RSA private key" : "RSA秘密鍵",
    "Private key" : "秘密鍵",
    "Kerberos ticket" : "ケルベロスチケット",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "バケット名",
    "Hostname" : "ホスト名",
    "Port" : "ポート",
    "Region" : "リージョン",
    "Enable SSL" : "SSLを有効",
    "Enable Path Style" : "パス形式を有効",
    "Legacy (v2) authentication" : "レガシー認証(v2)",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "リモートサブフォルダー",
    "Secure https://" : "セキュア https://",
    "FTP" : "FTP",
    "Host" : "ホスト",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "ローカル",
    "Location" : "場所",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "ルート",
    "SFTP with secret key login" : "秘密鍵でSFTPログイン",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "共有",
    "SMB / CIFS using OC login" : "Nextcloud ログインを利用したSMB / CIFS",
    "Username as share" : "共有名",
    "OpenStack Object Storage" : "OpenStack ObjectStorage",
    "Service name" : "サービス名",
    "Request timeout (seconds)" : "リクエストがタイムアウトするまでの秒数",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHPでのcURLのサポートが有効になっていないか、インストールされていません。 %s のマウントは不可能です。システム管理者にインストールを依頼してください。",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHPのFTPサポートが有効になっていないか、インストールされていません。%s のマウントは不可能です。システム管理者にインストールを依頼してください。",
    "External storage support" : "外部ストレージのサポート",
    "Adds basic external storage support" : "基本的な外部ストレージのサポートを追加",
    "No external storage configured or you don't have the permission to configure them" : "外部ストレージが設定されていないか、外部ストレージを設定する権限がありません",
    "Name" : "名前",
    "Storage type" : "ストレージ種別",
    "Scope" : "スコープ",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "外部ストレージを使用すると、外部ストレージサービスおよびデバイスをセカンダリのNextcloudストレージデバイスとしてマウントできます。 また、ユーザーが独自の外部ストレージサービスをマウントできるようにすることもできます。",
    "Folder name" : "フォルダー名",
    "External storage" : "外部ストレージ",
    "Authentication" : "認証",
    "Configuration" : "設定",
    "Available for" : "利用可能",
    "Click to recheck the configuration" : "クリックすると設定が再確認されます",
    "Add storage" : "ストレージを追加",
    "Advanced settings" : "詳細設定",
    "Allow users to mount external storage" : "ユーザーに外部ストレージの接続を許可する",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "グローバル資格情報を使用して、同じ資格情報を持つ複数の外部記憶装置で認証することができます。",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "リクエストトークンの取得に失敗しました。アプリのキーとパスワードが正しいことを確認してください。",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "アクセストークンの取得に失敗しました。アプリのキーとパスワードが正しいことを確認してください。",
    "Step 1 failed. Exception: %s" : "ステップ 1 の実行に失敗しました。例外: %s",
    "Step 2 failed. Exception: %s" : "ステップ 2 の実行に失敗しました。例外: %s",
    "Dropbox App Configuration" : "Dropbox アプリ設定",
    "Google Drive App Configuration" : "Google アプリ設定",
    "OpenStack" : "OpenStack",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\"はインストールされていません。 %s のマウントは不可能です。システム管理者にインストールを依頼してください。",
    "No external storage configured" : "外部ストレージは設定されていません",
    "You can add external storages in the personal settings" : "個人設定で外部ストレージを設定することができます。",
    "Allow users to mount the following external storage" : "ユーザーに次の外部ストレージのマウントを許可する",
    "Are you sure you want to delete this external storage" : "この外部ストレージを本当に削除しますか?"
},
"nplurals=1; plural=0;");
